@@ -115,6 +115,7 @@ from .phonenumberutil import (COUNTRY_CODE_TO_REGION_CODE, SUPPORTED_REGIONS,
                               national_significant_number,
                               ndd_prefix_for_region,
                               normalize_digits_only,
+                              normalize_diallable_chars_only,
                               number_type,
                               parse,
                               region_code_for_country_code,
@@ -131,13 +132,14 @@ from .shortnumberinfo import (ShortNumberCost,
                               expected_cost,
                               connects_to_emergency_number,
                               is_emergency_number,
-                              is_carrier_specific)
+                              is_carrier_specific,
+                              is_carrier_specific_for_region)
 from .phonenumbermatcher import PhoneNumberMatch, PhoneNumberMatcher, Leniency
 
 
 # Version number is taken from the upstream libphonenumber version
 # together with an indication of the version of the Python-specific code.
-__version__ = "8.0.1"
+__version__ = "8.3.1"
 
 __all__ = ['PhoneNumber', 'CountryCodeSource', 'FrozenPhoneNumber',
            'REGION_CODE_FOR_NON_GEO_ENTITY', 'NumberFormat', 'PhoneNumberDesc', 'PhoneMetadata',
@@ -179,6 +181,7 @@ __all__ = ['PhoneNumber', 'CountryCodeSource', 'FrozenPhoneNumber',
            'national_significant_number',
            'ndd_prefix_for_region',
            'normalize_digits_only',
+           'normalize_diallable_chars_only',
            'number_type',
            'parse',
            'region_code_for_country_code',
@@ -198,6 +201,7 @@ __all__ = ['PhoneNumber', 'CountryCodeSource', 'FrozenPhoneNumber',
            'connects_to_emergency_number',
            'is_emergency_number',
            'is_carrier_specific',
+           'is_carrier_specific_for_region',
            # end of items from shortnumberinfo.py
            'PhoneNumberMatch', 'PhoneNumberMatcher', 'Leniency',
            ]
